$(document).ready(function () {
  const phoneInput = document.querySelector("#phone");

  $("#messageSucess").hide();

  const iti = window.intlTelInput(phoneInput, {
      initialCountry: "auto",
      geoIpLookup: function (callback) {
          callback("cy");
      },
      loadUtilsOnInit: "https://cdn.jsdelivr.net/npm/intl-tel-input@24.6.0/build/js/utils.js",
  });

  function getLang() {
      const urlParams = new URLSearchParams(window.location.search);
      return urlParams.get("lang") || "en";
  }

  const lang = getLang();

  const messages = {
      en: {
          fnError: "First Name is required",
          lnError: "Last Name is required",
          emailError: "Email Address is required",
          emailInvalid: "Please enter a valid email",
          phoneError: "Phone Number is required",
          phoneInvalid: "Please enter a valid phone number",
          positionError: "Please select business type",
          messageError: "Message is required",
          submitError: "Something went wrong. Please try again.",
          submitSuccess: "Thank you for reaching out! A member of AccelPrime team will be in touch soon to discuss your liquidity needs.",
      },
  };

  function validateForm() {
      let isValid = true;
      $(".invalid-feedback").hide();

      if ($("#fn").val().trim() === "") {
          $("#fnError").text(messages[lang].fnError).show();
          isValid = false;
      }

      if ($("#ln").val().trim() === "") {
          $("#lnError").text(messages[lang].lnError).show();
          isValid = false;
      }

      const email = $("#email").val().trim();
      const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
      if (email === "") {
          $("#emailError").text(messages[lang].emailError).show();
          isValid = false;
      } else if (!emailRegex.test(email)) {
          $("#emailError").text(messages[lang].emailInvalid).show();
          isValid = false;
      }

      if (phoneInput.value.trim() === "") {
          $("#phoneError").text(messages[lang].phoneError).show();
          isValid = false;
      } else if (!iti.isValidNumber()) {
          $("#phoneError").text(messages[lang].phoneInvalid || "Please enter a valid phone number").show();
          isValid = false;
      }

      if ($("#position").val() === "") {
          $("#positionError").text(messages[lang].positionError).show();
          isValid = false;
      }

      if ($("#message").val().trim() === "") {
          $("#messageError").text(messages[lang].messageError).show();
          isValid = false;
      }

      return isValid;
  }

  $("#contact-form").on("submit", function (e) {
      e.preventDefault();
      $('#submitBtn').prop('disabled', true);

      if (validateForm()) {
          const formData = {
              fn: $("#fn").val().trim(),
              ln: $("#ln").val().trim(),
              email: $("#email").val().trim(),
              phone: iti.getNumber(),
              position: $("#position").val(),
              message: $("#message").val().trim(),
          };

          $.ajax({
              url: "./utils/send-email",
              type: "POST",
              data: formData,
              success: function (response) {
                  console.log(response);
                  if (response.status === "error") {
                    console.log("Error:", response.message);
                  } else {
                      $("#messageSucess").show().text(messages[lang].submitSuccess);
                      setTimeout(() => {
                          $("#messageSucess").hide();
                      }, 10000);

                      $("form").find('input[type="text"], input[type="email"], input[type="tel"], textarea').val("");
                  }
              },
              error: function (xhr, status, error) {
                console.log("XHR Object: ", xhr);
                console.log("Status: ", status);
                console.log("Error: ", error);
                console.log("Response Text: ", xhr.responseText);
            
                if (xhr.responseText) {
                    try {
                        var response = JSON.parse(xhr.responseText);
                        console.log("Parsed Response: ", response);
                    } catch (e) {
                        console.log("Error parsing response as JSON: ", e);
                    }
                } else {
                    console.log("Empty response from the server.");
                }
            }
            
            
          });
      }
      $('#submitBtn').prop('disabled', false);
  });
});
