const scene = new THREE.Scene();
const camera = new THREE.PerspectiveCamera(
  75,
  window.innerWidth / window.innerHeight,
  1,
  10000
);
const renderer = new THREE.WebGLRenderer({ antialias: true, alpha: true });
const amountX = 40;
const amountY = 100;
const spacer = 20;
const particlesCount = amountX * amountY;
let particles = null;
let count = 0;

// Dynamic wave parameters
const waveFrequencyX = 0.15;
const waveFrequencyY = 0.2;
const waveAmplitude = 75;
const waveSpeed = 0.05;

// Initialize Scene
function init() {
  const container = document.getElementById("threejs-container");
  container.appendChild(renderer.domElement);

  renderer.setPixelRatio(window.devicePixelRatio);
  renderer.setSize(container.clientWidth, container.clientHeight);
  renderer.setClearColor(0x000000, 0);

  camera.aspect = container.clientWidth / container.clientHeight;
  camera.updateProjectionMatrix();
  camera.position.x = 750;
  camera.position.y = -500;
  camera.lookAt(scene.position);

  const positions = new Float32Array(particlesCount * 3);
  let i = 0;
  const offsetY = -(container.clientHeight / 2);
  for (let ix = 0; ix < amountX; ix++) {
    for (let iy = 0; iy < amountY; iy++) {
      positions[i] = ix * spacer - (amountX * spacer) / 2;
      positions[i + 1] = offsetY;
      positions[i + 2] = iy * spacer - (amountY * spacer) / 2;
      i += 3;
    }
  }

  const geometry = new THREE.BufferGeometry();
  geometry.setAttribute("position", new THREE.BufferAttribute(positions, 3));

  const material = new THREE.PointsMaterial({ color: "#6366f1", size: 2 });

  particles = new THREE.Points(geometry, material);
  scene.add(particles);

  animate();
}

// Animation Loop
function animate() {
  requestAnimationFrame(animate);
  render();
}

// Render Scene
function render() {
  const positions = particles.geometry.attributes.position.array;
  let i = 0;
  for (let ix = 0; ix < amountX; ix++) {
    for (let iy = 0; iy < amountY; iy++) {
      positions[i + 1] =
        Math.sin((ix + count) * waveFrequencyX) * waveAmplitude +
        Math.sin((iy + count) * waveFrequencyY) * waveAmplitude;
      i += 3;
    }
  }
  particles.geometry.attributes.position.needsUpdate = true;
  renderer.render(scene, camera);
  count += waveSpeed;
}

// Resize Listener
function onWindowResize() {
  const container = document.getElementById("threejs-container");
  camera.aspect = container.clientWidth / container.clientHeight;
  camera.updateProjectionMatrix();
  renderer.setSize(container.clientWidth, container.clientHeight);
}

window.addEventListener("resize", onWindowResize);
init();
